🐪Camel (Open source go package)
What is Camel ?
Camel is a package for golang to make typing easy for first time you start golang.
Version
- Camel V1 (25.7.2026)
- Camel v1.1 (1.8.2026)
Structe of file
camel/
camel.go => file of camel
camelos/
camelos.go => file of camelos
go.mod => model and go version
LICENSE => mit license
main.go => test file
Installation
- 1 Open terminal in your file project and type this
go get github.com/Ghanmidev2012/camelv1
Command for camel
Commands of camel is easier.
package main
import (
"github.com/Ghanmidev2012/camelv1/camel"
)
func main() {
camel.PrCamel("hello type your name")
}
package main
import (
"github.com/Ghanmidev2012/camelv1/camel"
)
func main() {
camel.CamelWait(2)
}
- 3 Input command
For input command use this command
camel.CamelInput("type anythong")
This exemple:
package main
import (
"github.com/Ghanmidev2012/camelv1/camel"
)
func main() {
name := camel.CamelInput("type your name:")
camel.PrCamel(name)
}
- 4 Clear command
For clear anything in your terminal use this commmand:
camel.CamelClear()
This exemple:
package main
import (
"github.com/Ghanmidev2012/camelv1/camel"
)
func main() {
name := camel.CamelInput("type your name:")
camel.PrCamel(name)
}
- 5 os dedector
For check your os
operation systeme use this commnad:
package main
import (
"github.com/Ghanmidev2012/camelv1/camel"
"github.com/Ghanmidev2012/camelv1/camelos"
)
func main() {
if camelos.CamelWindows() {
camel.PrCamel("is windows")
} else if camelos.CamelLinux(){
camel.PrCamel("Is linux")
}
}
- 5 Create file and Open file
For create or open file type this command
camel.CamelCreateFile("adam.txt")
and to open file type
camel.CamelOpenFile("adam.txt")
Exemple for tow functions
package main
import (
"github.com/Ghanmidev2012/camelv1/camel"
)
func main(){
camel.CamelCreateFile("adam.txt")
camel.CamelOpenFile("adam.txt")
}
And there are athor thing commming soon !
Credits
Adam ghanmi Ghanmidev2012
LICENSE